@@ -2,14 +2,8 @@
 //
 //////////////////////////////////////////////////////////////////////
 
-//#include ""
 #include "abswordseg.h"
 #include "dictpath.h"
-#ifdef __APPLE__
-# include <stdlib.h>
-#else
-# include <malloc.h>
-#endif
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -19,32 +13,34 @@
 //////////////////////////////////////////////////////////////////////
 
 AbsWordSeg::AbsWordSeg(){ //Constructor
-	IdxSep = (short int*)malloc (MAXLEN*sizeof(short int));
-	LinkSep = (short int*)malloc(3*MAXLEN*sizeof(short int));
+	IdxSep = new short int [MAXLEN];
+	LinkSep = new short int [3*MAXLEN];
 	if ((IdxSep==NULL)||(LinkSep==NULL)){
 		printf("Cannot allocate memory\n");
-		delete MyDict;
 		exit(0);
 	}
 	cntSep=0;
 }
 
 AbsWordSeg::~AbsWordSeg(){// Destructor
-	delete IdxSep;
-	delete LinkSep;
+	delete[] IdxSep;
+	delete[] LinkSep;
 }
 
+#define tis2uni(c)  ((c)&0x80?((c)-0xa0+0x0e00):(c))
+
 void AbsWordSeg::CreateWordList(void){
 char Buff[2000];
 short int i,j,cntLink,en_word;
 short int cntFound,amb_sep_cnt;
 int data_idx;
 unsigned char lead_ch;
-State curState,terState;
+TrieState *curState;
 
-   strcpy(Buff,"");
+   Buff[0]='\0';
    cntLink=0;
    amb_sep_cnt=0;
+   curState=trie_root(MyDict);
    for(i=0;i<len;i++) { //word boundry start at i and end at j.
 	
      if ( !IsLeadChar((unsigned char)sen[i])||
@@ -84,23 +80,20 @@ State curState,terState;
        	continue;
       }
       cntFound=0;
-      curState=MyDict->StartState(0);
-	  j=-1;
-      do{
-         j++;
+      trie_state_rewind(curState);
+      for (j = 0; i+j<len; j++) {
 		 if ((sen[i+j]=='' )&&(cntFound!=0)) {//Mai-Ya-Mok -- Stop word point 17 July 2001
 			LinkSep[cntLink-1]=i+j+1;
 			break;
 		 }
-      	 curState=MyDict->Walk(curState,(Char )sen[i+j]);
-         if (MyDict->WalkResult()==CRASH){
+         if (!trie_state_walk(curState,tis2uni((unsigned char)sen[i+j]))) {
 		 	break;
 		 }
-         terState=MyDict->Terminate(curState);
-		 if( MyDict->WalkResult() == TERMINAL ){
-            data_idx=MyDict->GetKeyData(terState);
-			char *bsep;
-			bsep=(char *)&data_idx;
+		 if( trie_state_is_terminal(curState) ){
+            //TrieState *terState = trie_state_clone (curState);
+            //trie_state_walk (terState, TRIE_CHAR_TERM);
+            //data_idx=trie_state_get_data(terState);
+            //trie_state_free (terState);
 			//===========================================================
 			//found word in dictionary
             //To check word boundary,Is it should be segment or not????
@@ -110,13 +103,11 @@ State curState,terState;
 			   LinkSep[cntLink+1]=-1; //debug 24 nov
 			   //LinkSepDataIdx[cntLink]=data_idx;
                cntFound++;
-			}else{
-				continue;
+               if (cntFound==1) IdxSep[i]=cntLink;
+               cntLink++;
 			}
-            cntLink++;
-            if (cntFound==1) IdxSep[i]=cntLink-1;  //set IdxSep[i] value
          }//end if WalkResult
-	  } while (i+j<len) ; //end for j
+	  } //end for j
       if (cntFound==0)
       	IdxSep[i]=-1; //
       else if (cntFound < 2000){
@@ -124,32 +115,30 @@ State curState,terState;
       	LinkSep[cntLink++]=-1;
       }
    } //end for i
+   trie_state_free(curState);
 //   amb_sep[amb_sep_cnt].st_idx=-1;
 	LinkSep[cntLink]=-1; 
 	LinkSep[++cntLink]=-1; //add stop value;
 }
 
 bool AbsWordSeg::IsNumber(char *str){
-int i,sl;
-	sl=strlen(str);
-   for (i=0;i<sl;i++) {
-   	if ( (*(str+i)>='0'&&*(str+i)<='9') || (*(str+i)=='.') || (*(str+i)==',') )
-       	continue;
-      else
-         return false; //false == 0
-   }
-   return true; //true<>0
+    while (*str) {
+        if ((*str < '0' || *str > '9') && *str != '.' && *str != ',')
+            return false;
+        str++;
+    }
+    return true;
 }
 bool AbsWordSeg::IsEnglish(char *str){
-int i,sl;
-	sl=strlen(str);
-   for (i=0;i<sl;i++) {
-   	if ( (*(str+i)>='A'&&*(str+i)<='Z') || (*(str+i)>='a'&&*(str+i)<='b') || (*(str+i)=='.') || (*(str+i)=='-')||(*(str+i)==' ') )
-       	continue;
-      else
-         return false; //false == 0
-   }
-   return true; //true<>0
+    while (*str) {
+        if ((*str < 'A' || *str > 'Z') && (*str < 'a' || *str > 'z')
+            && (*str != '.') && (*str != '-') && (*str != ' '))
+        {
+            return false;
+        }
+        str++;
+    }
+    return true;
 }
 
 bool AbsWordSeg::IsLeadChar(unsigned char ch){
@@ -167,10 +156,10 @@ bool AbsWordSeg::IsLastChar(unsigned char ch){
 bool AbsWordSeg::Has_Karun(char* sen_ptr,short int *k_idx){
 short int i;
    *k_idx=-1;
-	for (i=1;i<=3;i++){
-      if (*(sen_ptr+i)=='\0')
-      	break;
-      if (*(sen_ptr+i)==-20){
+   for (i=1;i<=3;i++){
+      if (sen_ptr[i]=='\0')
+         break;
+      if ((unsigned char)sen_ptr[i]==0xec){
          *k_idx=i;
          return true;
       }
@@ -264,8 +253,7 @@ void AbsWordSeg::GetBestSen(int bestidx,char *wbr,char *outstr){
 int t;
 char buff[2000];
 
-	strcpy(outstr,"");
-	t=0;
+	*outstr='\0';
 	for (t=0;SepData[bestidx].Sep[t]!=len;t++){
 		GetWord(bestidx,t,buff);
 		strcat(outstr,buff);
@@ -273,6 +261,5 @@ char buff[2000];
     }
 	GetWord(bestidx,t,buff);
 	strcat(outstr,buff);
-	strcat(outstr,"\0");
 }
 
