@@ -9,14 +9,14 @@
 #pragma once
 #endif // _MSC_VER >= 1000
 
-#include "trie/trie.h"
+#include <datrie/trie.h>
 #include "worddef.h"
 
 class AbsWordSeg  
 {
 public:
 	AbsWordSeg();
-	~AbsWordSeg();
+	virtual ~AbsWordSeg();
 	bool WordSeg(char* senstr,char *output,char *wbr);
 	
 protected:
@@ -36,12 +36,12 @@ protected:
 	virtual unsigned short int copySepData(short int sourceIdxSen,short int targetIdxSen,short int sepPoint);
 	void GetWord(short int idxsen,short int idx,char *buff);
 	//============Check Character Type Function============
-	bool IsLeadChar(unsigned char ch);
-	bool IsLastChar(unsigned char ch);
-	bool IsNumber(char *str);
-	bool IsEnglish(char *str);
+	static bool IsLeadChar(unsigned char ch);
+	static bool IsLastChar(unsigned char ch);
+	static bool IsNumber(char *str);
+	static bool IsEnglish(char *str);
 	//============Check Karan rule=========================
-	bool Has_Karun(char* sen_ptr,short int *k_idx);
+	static bool Has_Karun(char* sen_ptr,short int *k_idx);
 };
 
 #endif // !defined(AFX_ABSWORDSEG_H__A0F72574_2912_11D3_B459_00105A5C2417__INCLUDED_)
