@@ -20,10 +20,6 @@ public:
 
 protected:
 	virtual int CreateSentence();
-private:
-	char *branchPath;
-	char *tailPath;
-
 };
 
 #endif // !defined(AFX_LONGWORDSEG_H__40352894_2A0D_11D3_B45C_00105A5C2417__INCLUDED_)
