@@ -36,10 +36,6 @@
 // 4: not found pbranch.tri
 // 5: not found dtail.tri
 // 6: not found ptail.tri
-char *method=NULL;
-char mulestr[5];
-char buff[2000],gout[5000];
-char *startStr;
 
 int myisspace(int ch);
 int SplitToken(char **str, char *token);
@@ -48,52 +44,44 @@ void RemoveJunkChar(char *str);
 
 
 
-int InitWordSegmentation(const char *wordsegdata, AbsWordSeg **wseg)
+int InitWordSegmentation(const char *wordsegdata,
+                         const char *method,
+                         AbsWordSeg **pWseg)
 {
-  int wsegpathlen = strlen(wordsegdata);
   FILE* fp;
 
-
-  d2branchpath = new char[wsegpathlen + 2 + strlen(D2BRANCH)];
-  strcpy(d2branchpath, wordsegdata);
-  strcat(d2branchpath, PATHSEPERATOR);
-  strcat(d2branchpath, D2BRANCH);    //printf("%s\n", dbranchpath); fflush(stdout);
-  if ((fp = fopen(d2branchpath, "r")) == NULL) 
+  char *d2triepath = new char[strlen(wordsegdata) + 2 + strlen(D2TRIE)];
+  strcpy(d2triepath, wordsegdata);
+  strcat(d2triepath, PATHSEPERATOR);
+  strcat(d2triepath, D2TRIE);    //printf("%s\n", dbranchpath); fflush(stdout);
+  if ((fp = fopen(d2triepath, "r")) == NULL) {
+	  delete[] d2triepath;
 	  return 1;
-  fclose(fp);
-
-  d2tailpath = new char[wsegpathlen + 2 + strlen(D2TAIL)];
-  strcpy(d2tailpath, wordsegdata);
-  strcat(d2tailpath, PATHSEPERATOR);
-  strcat(d2tailpath, D2TAIL);    //printf("%s\n", dtailpath); fflush(stdout);
-  if ((fp = fopen(d2tailpath, "r")) == NULL) 
-	  return 2;
+  }
+  delete[] d2triepath;
   fclose(fp);
 
   if (method==NULL){
-	  *wseg=new MaxWordSeg(wordsegdata);
+	  *pWseg=new MaxWordSeg(wordsegdata);
 	  return 0;
   }
   if (strcmp(method,"long")==0){
-	  *wseg=new LongWordSeg(wordsegdata);
+	  *pWseg=new LongWordSeg(wordsegdata);
   }else{
-	  *wseg=new MaxWordSeg(wordsegdata);
+	  *pWseg=new MaxWordSeg(wordsegdata);
   }
-  delete method;
   return 0;
 }
 
-void ExitWordSegmentation(AbsWordSeg **wseg)
+void ExitWordSegmentation(AbsWordSeg *wseg)
 {
-  delete d2branchpath;
-  delete d2tailpath;
-  delete *wseg;
+  delete wseg;
 }
 
-void WordSegmentation(AbsWordSeg **wseg, char *wbr, char *line, char* output)
+void WordSegmentation(AbsWordSeg *wseg, char *wbr, char *line, char* output)
 {
 	//RemoveJunkChar(line);
-	(*wseg)->WordSeg(line,output,wbr);
+	wseg->WordSeg(line,output,wbr);
 }
 
 static void Usage(int verbose)
@@ -138,20 +126,22 @@ int main(int argc, char *argv[])
   char mode = 1;  // 0 = display, 1 = don't display message
   char *wbr = new char[20];
   char *wsegpath = NULL;
+  char *method=NULL;
   char *fileformat = NULL;
   char *unicode = NULL;
+  bool muleMode;
   bool thaifag;
   bool wholeLine=false;
   
   strcpy(wbr, "|");
-  strcpy(mulestr,"");
+  muleMode = false;
   for (int iargc = 1; iargc < argc; iargc++) {
     if (strcmp("mule", argv[iargc]) == 0){
-      strcpy(mulestr,"mule");
+      muleMode = true;
       mode = 1;
     } else if (strcmp("-b", argv[iargc]) == 0 && iargc + 1 < argc) {
       iargc++;
-      delete wbr;
+      delete[] wbr;
       wbr = new char[strlen(argv[iargc]) + 1];
       strcpy(wbr, argv[iargc]);
     } else if (strcmp("-d", argv[iargc]) == 0 && iargc + 1 < argc) {
@@ -181,19 +171,19 @@ int main(int argc, char *argv[])
                strcmp("--help", argv[iargc]) == 0)
     {
       Usage(1);
-      delete wbr;
-      delete wsegpath;
-      delete fileformat;
-      delete method;
-      delete unicode;
+      delete[] wbr;
+      delete[] wsegpath;
+      delete[] fileformat;
+      delete[] method;
+      delete[] unicode;
       return 1;
     } else {
       Usage(0);
-      delete wbr;
-      delete wsegpath;
-      delete fileformat;
-      delete method;
-      delete unicode;
+      delete[] wbr;
+      delete[] wsegpath;
+      delete[] fileformat;
+      delete[] method;
+      delete[] unicode;
       return 1;
     }
   }
@@ -220,16 +210,17 @@ int main(int argc, char *argv[])
   char leadch[3],folch[3];
   int retval;
 
-  if  (( retval=InitWordSegmentation(".", &wseg)) > 0)
-	  retval=InitWordSegmentation(wsegpath, &wseg);
+  if  (( retval=InitWordSegmentation(".", method, &wseg)) > 0)
+	  retval=InitWordSegmentation(wsegpath, method, &wseg);
 
-  delete wsegpath;
+  delete[] wsegpath;
+  delete[] method;
   if (retval > 0) {
-    delete wbr;
+    delete[] wbr;
     return 1;
   }
-  strcpy(leadch,"");
-  strcpy(folch,"");
+  leadch[0]='\0';
+  folch[0]='\0';
 
 
 
@@ -257,28 +248,29 @@ int main(int argc, char *argv[])
 			FltX->Print(line,thaifag);
 			continue;
 		}
-		WordSegmentation(&wseg, wbr, line, output);
+		WordSegmentation(wseg, wbr, line, output);
 		FltX->Print(output,thaifag);
 	  }
 	  delete FltX;
   }else{
 	  char stopstr[20];
-	  if (strcmp(mulestr,"mule")==0)
+	  if (muleMode)
 		strcpy(stopstr,wbr);
 	  else
-		strcpy(stopstr,"");
+		stopstr[0]='\0';
 	  for (;;) { // read until end of file.
 		if (mode == 0) printf("Input : ");
 		for (i = 0; ((c = fgetc(tmpin)) != '\n')
 			&& (i <= MAXCHAR) && (c!=EOF);i++) 
 			line[i] = (char)c;
 		line[i] = 0;
-		strcpy(gout,"");
 		//if (strcmp(line, "exit") == 0) break;
-		if (strcmp(line,"")==0) 
+		if (line[0]=='\0') 
 			if (c==EOF) break; else continue;
 		int tokenFlag;
-		startStr=line;
+		char *startStr=line;
+		char buff[2000],gout[5000];
+		gout[0] = '\0';
 		if (!wholeLine) {
  			while ((tokenFlag=SplitToken(&startStr,buff))>=0) {
 				if (tokenFlag==-1)
@@ -286,13 +278,13 @@ int main(int argc, char *argv[])
 				if (tokenFlag==0) {
 					strcat(gout,buff);
 				} else {
-					WordSegmentation(&wseg, wbr, buff, output);
+					WordSegmentation(wseg, wbr, buff, output);
 					strcat(gout,output);
 				}
 				strcat(gout, wbr);
 			}
 		}else{
-			WordSegmentation(&wseg, wbr, line, output);
+			WordSegmentation(wseg, wbr, line, output);
 			strcpy(gout,output);
 			strcat(gout,stopstr);
 		}
@@ -310,12 +302,12 @@ int main(int argc, char *argv[])
 	  if (unicode[0]=='u') {
 		fclose(tmpin);
 	  }
-	  delete unicode;
+	  delete[] unicode;
   }
 
-  delete fileformat;
-  delete wbr;
-  ExitWordSegmentation(&wseg);
+  delete[] fileformat;
+  delete[] wbr;
+  ExitWordSegmentation(wseg);
 
   return 0;
 }
